==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/acl/lang/zh-tw/lang.php <==
<?php
/**
 * Chinese(Traditional) language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author chinsan <chinsan@mail2000.com.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmai.com>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin <danny0838@pchome.com.tw>
 * @author Shuo-Ting Jian <shoting@gmail.com>
 * @author syaoranhinata@gmail.com
 * @author Ichirou Uchiki <syaoranhinata@gmail.com>
 */
$lang['admin_acl']             = '管理存取控制表 (ACL)';
$lang['acl_group']             = '群組';
$lang['acl_user']              = '使用者';
$lang['acl_perms']             = '設定權限於';
$lang['page']                  = '頁面';
$lang['namespace']             = '分類名稱';
$lang['btn_select']            = '選擇';
$lang['p_user_id']             = '使用者 <b class="acluser">%s</b> 目前在頁面 <b class="aclpage">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_user_ns']             = '使用者 <b class=\"acluser\">%s</b> 目前在分類名稱 <b class=\"aclns\">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_group_id']            = '群組 <b class="aclgroup">%s</b> 的成員目前在頁面 <b class="aclpage">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_group_ns']            = '群組 <b class=\"aclgroup\">%s</b> 的成員目前在分類名稱 <b class=\"aclns\">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_choose_id']           = '請在上方表格<b>輸入使用者或群組</b>以檢視或編輯頁面 <b class="aclpage">%s</b> 的權限設定。';
$lang['p_choose_ns']           = '請在上方表格<b>輸入使用者或群組</b>以檢視或編輯分類名稱 <b class=\"aclns\">%s</b> 的權限設定。';
$lang['p_inherited']           = '注意：這些權限並未明確指定，它們是從群組或上層的分類名稱繼承而來。';
$lang['p_isadmin']             = '注意：選取的群組或使用者擁有完整權限，因為他或他們已成為超級使用者。';
$lang['p_include']             = '較高的權限亦包含了較低的權限。新增、上傳與刪除權限只能套用至分類名稱，不能套用至頁面。';
$lang['current']               = '目前的存取控制規則';
$lang['where']                 = '頁面/分類名稱';
$lang['who']                   = '使用者/群組';
$lang['perm']                  = '權限';
$lang['acl_perm0']             = '無';
$lang['acl_perm1']             = '讀取頁面';
$lang['acl_perm2']             = '編輯頁面';
$lang['acl_perm4']             = '新增頁面';
$lang['acl_perm8']             = '上傳圖檔';
$lang['acl_perm16']            = '刪除檔案';
$lang['acl_new']               = '增加規則';
$lang['acl_mod']               = '修改規則';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/acl/lang/zh-tw/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author chinsan <chinsan@mail2000.com.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin <danny0838@pchome.com.tw>
 * @author Shuo-Ting Jian <shoting@gmail.com>
 * @author syaoranhinata <syaoranhinata@gmail.com>
 */
$lang['admin_acl']             = '管理存取控制表 (ACL)';
$lang['acl_group']             = '群組:';
$lang['acl_user']              = '使用者:';
$lang['acl_perms']             = '設定權限於';
$lang['page']                  = '頁面';
$lang['namespace']             = '分類名稱';
$lang['btn_select']            = '選擇';
$lang['p_user_id']             = '使用者 <b class="acluser">%s</b> 目前在頁面 <b class="aclpage">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_user_ns']             = '使用者 <b class=\"acluser\">%s</b> 目前在分類名稱 <b class=\"aclns\">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_group_id']            = '群組 <b class="aclgroup">%s</b> 的成員目前在頁面 <b class="aclpage">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_group_ns']            = '群組 <b class=\"aclgroup\">%s</b> 的成員目前在分類名稱 <b class=\"aclns\">%s</b> 裏擁有以下權限：<i>%s</i>。';
$lang['p_choose_id']           = '請在上方表格<b>輸入使用者或群組</b>以檢視或編輯頁面 <b class="aclpage">%s</b> 的權限設定。';
$lang['p_choose_ns']           = '請在上方表格<b>輸入使用者或群組</b>以檢視或編輯分類名稱 <b class=\"aclns\">%s</b> 的權限設定。';
$lang['p_inherited']           = '注意：這些權限並未明確指定，它們是從群組或上層的分類名稱繼承而來。';
$lang['p_isadmin']             = '注意：選取的群組或使用者擁有完整權限，因為他或他們已成為超級使用者。';
$lang['p_include']             = '較高的權限亦包含了較低的權限。新增、上傳與刪除權限只能套用至分類名稱，不能套用至頁面。';
$lang['current']               = '目前的存取控制規則';
$lang['where']                 = '頁面/分類名稱';
$lang['who']                   = '使用者/群組';
$lang['perm']                  = '權限';
$lang['acl_perm0']             = '無';
$lang['acl_perm1']             = '讀取頁面';
$lang['acl_perm2']             = '編輯頁面';
$lang['acl_perm4']             = '新增頁面';
$lang['acl_perm8']             = '上傳圖檔';
$lang['acl_perm16']            = '刪除檔案';
$lang['acl_new']               = '增加規則';
$lang['acl_mod']               = '修改規則';
